SqfliteWebSetupOptions class

Setup options.

Constructors

SqfliteWebSetupOptions({String? path, String? dir, bool? force, bool? verbose, Uri? sqlite3WasmUri, bool? noSqlite3Wasm, String? sqlite3WasmFilename, String? sqfliteWebWorkerFilename})
Setup options.

Properties

dir ↔ String
Directory (web by default). relative
latefinal
force ↔ bool
If true a clean build is made.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
noSqlite3Wasm ↔ bool
Don't fetch sqlite3 wasm
latefinal
path ↔ String
Project path (current directory by default). absolute
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqfliteWebWorkerFilename → String?
Web worker local file (default to sqflite_sw.js or read from pubspec)
final
sqlite3WasmFilename → String?
Sqlite3 wasm local file (default to sqlite3.wasm)
final
sqlite3WasmUri ↔ Uri
Sqlite3 wasm uri
latefinal
verbose ↔ bool
Verbose mode.
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited